  function C = MatMatSax(A,B)
%
% Pre:
%    A     m-by-p matrix.
%    B     p-by-n matrix
%
% Post:
%    C     A*B (Saxpy Version)
%
   [m,p] = size(A);
   [p,n] = size(B);
   C = zeros(m,n);
   for j=1:n
      % Compute j-th column of C.
      for k=1:p
         C(:,j) = C(:,j) + A(:,k)*B(k,j);
	  end
   end;
